@@ -8,11 +8,11 @@
 // to a raw hash map.
 
 #include <string.h>
+#include "basic.h"
 #include "hashfuncs.h"
-#include "openhashmap.h"
+#include "ohashmap.h"
 
-#define eq_opt(a,b) (strcmp((a),(b)) == 0)
-declareOpenHashMap(OptionMapRep,char const*,char const*,hash_string,eq_opt)
+declareOpenHashMap(OptionMapRep,char const*,char const*,hash_string,cmp_string)
 
 typedef OptionMapRep_Bindings OptionMap_Bindings;
 
