@@ -10,7 +10,7 @@
  * is removed, or the table is deleted.
  */
 
-#include "misc_tcl.h"
+#include <tcl.h>
 
 class HandleTable {
   public:
